@@ -3,4 +3,4 @@ from CyvoreOS.Plugins.abuseIPDB_plugin import run_check
 from CyvoreOS.Plugins.whois_plugin import run_check
 from CyvoreOS.Plugins.cryptoWalletValidator_plugin import run_check
 from CyvoreOS import checkObject
-from CyvoreOS.Scan import listplugins, scanstring
\ No newline at end of file
+from CyvoreOS.Scan import scanUrl, scan_one_string
\ No newline at end of file
